@@ -109,4 +109,13 @@ class level:
             return xplvlarr
         else:
             level.AddUser(system, user)
-            return [0, 0, level.CalcLevelXP(save.GetInt(f'{user}_{system}_lvl'))]
\ No newline at end of file
+            return [0, 0, level.CalcLevelXP(save.GetInt(f'{user}_{system}_lvl'))]
+    
+    def BestLevel(system : str):
+        bestlvl = 0
+        user = ''
+        for x in save.GetStrArr(system):
+            if save.GetInt(f'{user}_{system}_lvl') > bestlvl:
+                bestlvl = save.GetInt(f'{user}_{system}_lvl')
+                user = x
+        return [user, level]
